pub struct ContextProvenance {
pub revision_id: String,
pub kind: AnnotationKind,
pub attribution: String,
pub source_hash: Option<ContentHash>,
pub created_at_state: Option<StateId>,
}Expand description
Evidence captured by the authoring context command. This remains inside the signed native operation even when a hosted view does not project every field.
Fields
revision_id: Stringkind: AnnotationKindattribution: Stringsource_hash: Option<ContentHash>created_at_state: Option<StateId>Trait Implementations
Sourceimpl Clone for ContextProvenance
impl Clone for ContextProvenance
Sourceimpl Debug for ContextProvenance
impl Debug for ContextProvenance
Sourceimpl<'de> Deserialize<'de> for ContextProvenance
impl<'de> Deserialize<'de> for ContextProvenance
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ContextProvenance
Sourceimpl PartialEq for ContextProvenance
impl PartialEq for ContextProvenance
Sourceimpl Serialize for ContextProvenance
impl Serialize for ContextProvenance
impl StructuralPartialEq for ContextProvenance