pub fn apply_tree_delta(
anchor: &Tree,
ops: &[TreeDeltaOp],
) -> Result<Tree, TreeStreamError>Expand description
Apply a sorted cumulative delta to its materialized anchor.
pub fn apply_tree_delta(
anchor: &Tree,
ops: &[TreeDeltaOp],
) -> Result<Tree, TreeStreamError>Apply a sorted cumulative delta to its materialized anchor.