pub fn tree_delta(anchor: &Tree, current: &Tree) -> Vec<TreeDeltaOp>Expand description
Compute the sorted cumulative edit from anchor to current.
pub fn tree_delta(anchor: &Tree, current: &Tree) -> Vec<TreeDeltaOp>Compute the sorted cumulative edit from anchor to current.