pub struct Principal {
pub name: Vec<u8>,
pub email: Vec<u8>,
}Expand description
Human identity accountable for changes.
Fields
name: Vec<u8>Human-readable name bytes, preserved exactly from the source identity.
email: Vec<u8>Email address bytes, preserved exactly from the source identity.
Implementations